Conway's game of life
=====================

Conway's Game of Life implemention with pygame

Installation
............

Install with pip::

  pip install GameofLife

Install from source::

  python3 setup.py install


Running
.......

Run via launch script installed with pip package::
  
  GameofLife

Run as a Python module::

  python -m GameofLife
    

Using inside of code
.....................

To import the class in your own code::

  from LifeGame import LifeGame
  LifeGme().run()

Controls
........

- q --> quit
- s --> pause 
- r--> randomize

Contact
.......

Oscar Ozorio <osvaldo15963@fpuna.edu.py>




